# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal


class ExtendedFilePickerElementIds(object):
    """
    Const

    These constants are used to specify extended controls of a FilePicker dialog. A FilePicker service may be initialized so that it has additional controls extending the set of common controls a FilePicker usually supports.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API ExtendedFilePickerElementIds <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExtendedFilePickerElementIds.html>`_
    """
    CHECKBOX_AUTOEXTENSION: Literal[100]
    CHECKBOX_PASSWORD: Literal[101]
    CHECKBOX_FILTEROPTIONS: Literal[102]
    CHECKBOX_READONLY: Literal[103]
    CHECKBOX_LINK: Literal[104]
    CHECKBOX_PREVIEW: Literal[105]
    PUSHBUTTON_PLAY: Literal[106]
    LISTBOX_VERSION: Literal[107]
    LISTBOX_TEMPLATE: Literal[108]
    LISTBOX_IMAGE_TEMPLATE: Literal[109]
    CHECKBOX_SELECTION: Literal[110]
    LISTBOX_VERSION_LABEL: Literal[207]
    LISTBOX_TEMPLATE_LABEL: Literal[208]
    LISTBOX_IMAGE_TEMPLATE_LABEL: Literal[209]
    LISTBOX_FILTER_SELECTOR: Literal[210]
    CHECKBOX_GPGENCRYPTION: Literal[211]
    LISTBOX_IMAGE_ANCHOR: Literal[212]
    LISTBOX_IMAGE_ANCHOR_LABEL: Literal[213]

