# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
"""
Const


See Also:
    `API ConditionFormatOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html>`_
"""
EQUAL: Literal[0]
LESS: Literal[1]
GREATER: Literal[2]
LESS_EQUAL: Literal[3]
GREATER_EQUAL: Literal[4]
NOT_EQUAL: Literal[5]
BETWEEN: Literal[6]
NOT_BETWEEN: Literal[7]
DUPLICATE: Literal[8]
UNIQUE: Literal[9]
TOP_N_ELEMENTS: Literal[10]
BOTTOM_N_ELEMENTS: Literal[11]
TOP_N_PERCENT: Literal[12]
BOTTOM_N_PERCENT: Literal[13]
ABOVE_AVERAGE: Literal[14]
BELOW_AVERAGE: Literal[15]
ABOVE_EQUAL_AVERAGE: Literal[16]
BELOW_EQUAL_AVERAGE: Literal[17]
ERROR: Literal[18]
NO_ERROR: Literal[19]
BEGINS_WITH: Literal[20]
ENDS_WITH: Literal[21]
CONTAINS: Literal[22]
NOT_CONTAINS: Literal[23]
EXPRESSION: Literal[24]

