# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.frame.app_dispatch_provider import AppDispatchProvider as AppDispatchProvider
from .._pyi.frame.auto_recovery import AutoRecovery as AutoRecovery
from .._pyi.frame.bibliography import Bibliography as Bibliography
from .._pyi.frame.border_widths import BorderWidths as BorderWidths
from .._pyi.frame.components import Components as Components
from .._pyi.frame.content_handler import ContentHandler as ContentHandler
from .._pyi.frame.content_handler_factory import ContentHandlerFactory as ContentHandlerFactory
from .._pyi.frame.control_command import ControlCommand as ControlCommand
from .._pyi.frame.control_event import ControlEvent as ControlEvent
from .._pyi.frame.controller import Controller as Controller
from .._pyi.frame.desktop import Desktop as Desktop
from .._pyi.frame.desktop_task import DesktopTask as DesktopTask
from .._pyi.frame.desktop_tasks import DesktopTasks as DesktopTasks
from .._pyi.frame.dispatch_descriptor import DispatchDescriptor as DispatchDescriptor
from .._pyi.frame.dispatch_helper import DispatchHelper as DispatchHelper
from .._pyi.frame.dispatch_information import DispatchInformation as DispatchInformation
from .._pyi.frame.dispatch_provider import DispatchProvider as DispatchProvider
from .._pyi.frame.dispatch_recorder import DispatchRecorder as DispatchRecorder
from .._pyi.frame.dispatch_recorder_supplier import DispatchRecorderSupplier as DispatchRecorderSupplier
from .._pyi.frame.dispatch_result_event import DispatchResultEvent as DispatchResultEvent
from .._pyi.frame.dispatch_statement import DispatchStatement as DispatchStatement
from .._pyi.frame.document_templates import DocumentTemplates as DocumentTemplates
from .._pyi.frame.double_initialization_exception import DoubleInitializationException as DoubleInitializationException
from .._pyi.frame.feature_state_event import FeatureStateEvent as FeatureStateEvent
from .._pyi.frame.frame import Frame as Frame
from .._pyi.frame.frame_action_event import FrameActionEvent as FrameActionEvent
from .._pyi.frame.frame_control import FrameControl as FrameControl
from .._pyi.frame.frame_loader import FrameLoader as FrameLoader
from .._pyi.frame.frame_loader_factory import FrameLoaderFactory as FrameLoaderFactory
from .._pyi.frame.frames_container import FramesContainer as FramesContainer
from .._pyi.frame.global_event_broadcaster import GlobalEventBroadcaster as GlobalEventBroadcaster
from .._pyi.frame.illegal_argument_io_exception import IllegalArgumentIOException as IllegalArgumentIOException
from .._pyi.frame.layout_manager import LayoutManager as LayoutManager
from .._pyi.frame.media_type_detection_helper import MediaTypeDetectionHelper as MediaTypeDetectionHelper
from .._pyi.frame.module_manager import ModuleManager as ModuleManager
from .._pyi.frame.office_frame_loader import OfficeFrameLoader as OfficeFrameLoader
from .._pyi.frame.popup_menu_controller import PopupMenuController as PopupMenuController
from .._pyi.frame.popup_menu_controller_factory import PopupMenuControllerFactory as PopupMenuControllerFactory
from .._pyi.frame.protocol_handler import ProtocolHandler as ProtocolHandler
from .._pyi.frame.session_listener import SessionListener as SessionListener
from .._pyi.frame.session_manager import SessionManager as SessionManager
from .._pyi.frame.settings import Settings as Settings
from .._pyi.frame.start_module import StartModule as StartModule
from .._pyi.frame.statusbar_controller import StatusbarController as StatusbarController
from .._pyi.frame.statusbar_controller_factory import StatusbarControllerFactory as StatusbarControllerFactory
from .._pyi.frame.synchronous_frame_loader import SynchronousFrameLoader as SynchronousFrameLoader
from .._pyi.frame.task import Task as Task
from .._pyi.frame.task_creator import TaskCreator as TaskCreator
from .._pyi.frame.template_access import TemplateAccess as TemplateAccess
from .._pyi.frame.termination_veto_exception import TerminationVetoException as TerminationVetoException
from .._pyi.frame.title_changed_event import TitleChangedEvent as TitleChangedEvent
from .._pyi.frame.toolbar_controller import ToolbarController as ToolbarController
from .._pyi.frame.toolbar_controller_factory import ToolbarControllerFactory as ToolbarControllerFactory
from .._pyi.frame.transient_documents_document_content_factory import TransientDocumentsDocumentContentFactory as TransientDocumentsDocumentContentFactory
from .._pyi.frame.ui_command_description import UICommandDescription as UICommandDescription
from .._pyi.frame.unknown_module_exception import UnknownModuleException as UnknownModuleException
from .._pyi.frame.x_app_dispatch_provider import XAppDispatchProvider as XAppDispatchProvider
from .._pyi.frame.x_border_resize_listener import XBorderResizeListener as XBorderResizeListener
from .._pyi.frame.x_browse_history_registry import XBrowseHistoryRegistry as XBrowseHistoryRegistry
from .._pyi.frame.x_component_loader import XComponentLoader as XComponentLoader
from .._pyi.frame.x_component_registry import XComponentRegistry as XComponentRegistry
from .._pyi.frame.x_config_manager import XConfigManager as XConfigManager
from .._pyi.frame.x_control_notification_listener import XControlNotificationListener as XControlNotificationListener
from .._pyi.frame.x_controller import XController as XController
from .._pyi.frame.x_controller2 import XController2 as XController2
from .._pyi.frame.x_controller_border import XControllerBorder as XControllerBorder
from .._pyi.frame.x_desktop import XDesktop as XDesktop
from .._pyi.frame.x_desktop2 import XDesktop2 as XDesktop2
from .._pyi.frame.x_desktop_task import XDesktopTask as XDesktopTask
from .._pyi.frame.x_dispatch import XDispatch as XDispatch
from .._pyi.frame.x_dispatch_helper import XDispatchHelper as XDispatchHelper
from .._pyi.frame.x_dispatch_information_provider import XDispatchInformationProvider as XDispatchInformationProvider
from .._pyi.frame.x_dispatch_provider import XDispatchProvider as XDispatchProvider
from .._pyi.frame.x_dispatch_provider_interception import XDispatchProviderInterception as XDispatchProviderInterception
from .._pyi.frame.x_dispatch_provider_interceptor import XDispatchProviderInterceptor as XDispatchProviderInterceptor
from .._pyi.frame.x_dispatch_recorder import XDispatchRecorder as XDispatchRecorder
from .._pyi.frame.x_dispatch_recorder_supplier import XDispatchRecorderSupplier as XDispatchRecorderSupplier
from .._pyi.frame.x_dispatch_result_listener import XDispatchResultListener as XDispatchResultListener
from .._pyi.frame.x_document_templates import XDocumentTemplates as XDocumentTemplates
from .._pyi.frame.x_extended_filter_detection import XExtendedFilterDetection as XExtendedFilterDetection
from .._pyi.frame.x_filter_detect import XFilterDetect as XFilterDetect
from .._pyi.frame.x_frame import XFrame as XFrame
from .._pyi.frame.x_frame2 import XFrame2 as XFrame2
from .._pyi.frame.x_frame_action_listener import XFrameActionListener as XFrameActionListener
from .._pyi.frame.x_frame_loader import XFrameLoader as XFrameLoader
from .._pyi.frame.x_frame_loader_query import XFrameLoaderQuery as XFrameLoaderQuery
from .._pyi.frame.x_frame_set_model import XFrameSetModel as XFrameSetModel
from .._pyi.frame.x_frames import XFrames as XFrames
from .._pyi.frame.x_frames_supplier import XFramesSupplier as XFramesSupplier
from .._pyi.frame.x_global_event_broadcaster import XGlobalEventBroadcaster as XGlobalEventBroadcaster
from .._pyi.frame.x_infobar_provider import XInfobarProvider as XInfobarProvider
from .._pyi.frame.x_interceptor_info import XInterceptorInfo as XInterceptorInfo
from .._pyi.frame.x_layout_manager import XLayoutManager as XLayoutManager
from .._pyi.frame.x_layout_manager2 import XLayoutManager2 as XLayoutManager2
from .._pyi.frame.x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster
from .._pyi.frame.x_layout_manager_listener import XLayoutManagerListener as XLayoutManagerListener
from .._pyi.frame.x_load_event_listener import XLoadEventListener as XLoadEventListener
from .._pyi.frame.x_loadable import XLoadable as XLoadable
from .._pyi.frame.x_loader_factory import XLoaderFactory as XLoaderFactory
from .._pyi.frame.x_menu_bar_acceptor import XMenuBarAcceptor as XMenuBarAcceptor
from .._pyi.frame.x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor
from .._pyi.frame.x_model import XModel as XModel
from .._pyi.frame.x_model2 import XModel2 as XModel2
from .._pyi.frame.x_model3 import XModel3 as XModel3
from .._pyi.frame.x_module import XModule as XModule
from .._pyi.frame.x_module_manager import XModuleManager as XModuleManager
from .._pyi.frame.x_module_manager2 import XModuleManager2 as XModuleManager2
from .._pyi.frame.x_notifying_dispatch import XNotifyingDispatch as XNotifyingDispatch
from .._pyi.frame.x_popup_menu_controller import XPopupMenuController as XPopupMenuController
from .._pyi.frame.x_recordable_dispatch import XRecordableDispatch as XRecordableDispatch
from .._pyi.frame.x_session_manager_client import XSessionManagerClient as XSessionManagerClient
from .._pyi.frame.x_session_manager_listener import XSessionManagerListener as XSessionManagerListener
from .._pyi.frame.x_session_manager_listener2 import XSessionManagerListener2 as XSessionManagerListener2
from .._pyi.frame.x_status_listener import XStatusListener as XStatusListener
from .._pyi.frame.x_statusbar_controller import XStatusbarController as XStatusbarController
from .._pyi.frame.x_storable import XStorable as XStorable
from .._pyi.frame.x_storable2 import XStorable2 as XStorable2
from .._pyi.frame.x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController
from .._pyi.frame.x_synchronous_dispatch import XSynchronousDispatch as XSynchronousDispatch
from .._pyi.frame.x_synchronous_frame_loader import XSynchronousFrameLoader as XSynchronousFrameLoader
from .._pyi.frame.x_task import XTask as XTask
from .._pyi.frame.x_tasks_supplier import XTasksSupplier as XTasksSupplier
from .._pyi.frame.x_terminate_listener import XTerminateListener as XTerminateListener
from .._pyi.frame.x_terminate_listener2 import XTerminateListener2 as XTerminateListener2
from .._pyi.frame.x_title import XTitle as XTitle
from .._pyi.frame.x_title_change_broadcaster import XTitleChangeBroadcaster as XTitleChangeBroadcaster
from .._pyi.frame.x_title_change_listener import XTitleChangeListener as XTitleChangeListener
from .._pyi.frame.x_toolbar_controller import XToolbarController as XToolbarController
from .._pyi.frame.x_toolbar_controller_listener import XToolbarControllerListener as XToolbarControllerListener
from .._pyi.frame.x_transient_documents_document_content_factory import XTransientDocumentsDocumentContentFactory as XTransientDocumentsDocumentContentFactory
from .._pyi.frame.x_transient_documents_document_content_identifier_factory import XTransientDocumentsDocumentContentIdentifierFactory as XTransientDocumentsDocumentContentIdentifierFactory
from .._pyi.frame.xui_controller_factory import XUIControllerFactory as XUIControllerFactory
from .._pyi.frame.xui_controller_registration import XUIControllerRegistration as XUIControllerRegistration
from .._pyi.frame.x_untitled_numbers import XUntitledNumbers as XUntitledNumbers
from .._pyi.frame.x_url_list import XUrlList as XUrlList
from .._pyi.frame.x_window_arranger import XWindowArranger as XWindowArranger
from .._pyi.frame.the_auto_recovery import theAutoRecovery as theAutoRecovery
from .._pyi.frame.the_desktop import theDesktop as theDesktop
from .._pyi.frame.the_global_event_broadcaster import theGlobalEventBroadcaster as theGlobalEventBroadcaster
from .._pyi.frame.the_popup_menu_controller_factory import thePopupMenuControllerFactory as thePopupMenuControllerFactory
from .._pyi.frame.the_statusbar_controller_factory import theStatusbarControllerFactory as theStatusbarControllerFactory
from .._pyi.frame.the_toolbar_controller_factory import theToolbarControllerFactory as theToolbarControllerFactory
from .._pyi.frame.the_ui_command_description import theUICommandDescription as theUICommandDescription
