# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal


class EntryInitModes(object):
    """
    Const

    This constant set contains possible modes to initialize object persistence.

    See Also:
        `API EntryInitModes <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EntryInitModes.html>`_
    """
    DEFAULT_INIT: Literal[0]
    """
    In case object persistence is created based on existing entry, the object should be initialized from this entry.
    
    Otherwise the object should be initialized as a new one.
    """
    TRUNCATE_INIT: Literal[1]
    """
    The object should be initialized as a new empty one.
    """
    NO_INIT: Literal[2]
    """
    The object should be initialized as a new one only in case it still was not initialized.
    
    If the object initialized already do not reinitialize it.
    """
    MEDIA_DESCRIPTOR_INIT: Literal[3]
    """
    The object should be initialized using additional arguments from provided com.sun.star.document.MediaDescriptor.
    """
    URL_LINK_INIT: Literal[4]
    """
    The object should be initialized as a link using URL provided in additional arguments.
    """

