# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XViewFreezable(XInterface_8f010a43):
    """
    enables a SpreadsheetView to freeze columns and rows of the view.

    See Also:
        `API XViewFreezable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XViewFreezable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XViewFreezable']

    def freezeAtPosition(self, nColumns: int, nRows: int) -> None:
        """
        freezes panes with the specified number of columns and rows.
        
        To freeze only horizontally, specify nRows as 0. To freeze only vertically, specify nColumns as 0.
        """
    def hasFrozenPanes(self) -> bool:
        """
        returns TRUE if the view has frozen panes.
        
        Only one of XViewSplitable.getIsWindowSplit() and XViewFreezable.hasFrozenPanes() can be TRUE.
        """

