# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .formula_token import FormulaToken as FormulaToken_bd1c0bf8


class FormulaOpCodeMapEntry(object):
    """
    Struct Class

    contains a mapping from a formula name (function name, operator, ...) to the OpCode used by the formula compiler.

    See Also:
        `API FormulaOpCodeMapEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1FormulaOpCodeMapEntry.html>`_
    """
    typeName: Literal['com.sun.star.sheet.FormulaOpCodeMapEntry']

    def __init__(self, Name: typing.Optional[str] = ..., Token: typing.Optional[FormulaToken_bd1c0bf8] = ...) -> None:
        """
        Constructor

        Arguments:
            Name (str, optional): Name value.
            Token (FormulaToken, optional): Token value.
        """


    @property
    def Name(self) -> str:
        """
        The function name, or operator.
        """


    @property
    def Token(self) -> FormulaToken_bd1c0bf8:
        """
        The corresponding mapping.
        """


