# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
"""
Const

These constants are used to specify a measure.

A component using these constants may not support all units.

See Also:
    `API MeasureUnit <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1MeasureUnit.html>`_
"""
MM_100TH: Literal[0]
"""
all measures for this component are in 100th millimeter
"""
MM_10TH: Literal[1]
"""
all measures for this component are in 10th millimeter
"""
MM: Literal[2]
"""
all measures for this component are in millimeter
"""
CM: Literal[3]
"""
all measures for this component are in centimeters
"""
INCH_1000TH: Literal[4]
"""
all measures for this component are in 1000th inch
"""
INCH_100TH: Literal[5]
"""
all measures for this component are in 100th inch
"""
INCH_10TH: Literal[6]
"""
all measures for this component are in 10th inch
"""
INCH: Literal[7]
"""
all measures for this component are in inch
"""
POINT: Literal[8]
"""
all measures for this component are in points
"""
TWIP: Literal[9]
"""
all measures for this component are in twips
"""
M: Literal[10]
"""
all measures for this component are in meters
"""
KM: Literal[11]
"""
all measures for this component are in kilometers
"""
PICA: Literal[12]
"""
all measures for this component are in pica
"""
FOOT: Literal[13]
"""
all measures for this component are in foot
"""
MILE: Literal[14]
"""
all measures for this component are in miles
"""
PERCENT: Literal[15]
"""
all measures for this component are in percentage
"""
PIXEL: Literal[16]
"""
all measures for this component are in pixel
"""
APPFONT: Literal[17]
"""
all measures for this component are in APPFONT
"""
SYSFONT: Literal[18]
"""
all measures for this component are in SYSFONT
"""

