# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XScriptTypeDetector(XInterface_8f010a43):
    """
    contains the help routines for layouting complex text
    
    Assumption - StartPos is inclusive and EndPos is exclusive.
    
    The nScriptDirection parameters are of type ScriptDirection
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XScriptTypeDetector <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XScriptTypeDetector.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XScriptTypeDetector']

    def beginOfCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def beginOfScriptDirection(self, aText: str, nPos: int, nScriptDirection: int) -> int:
        """
        """
    def endOfCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def endOfScriptDirection(self, aText: str, nPos: int, nScriptDirection: int) -> int:
        """
        """
    def getCTLScriptType(self, aText: str, nPos: int) -> int:
        """
        """
    def getScriptDirection(self, aText: str, nPos: int, nDefaultScriptDirection: int) -> int:
        """
        """

