# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.bridge
from .x_bridge_factory2 import XBridgeFactory2 as XBridgeFactory2_ecc10d24

class BridgeFactory(XBridgeFactory2_ecc10d24):
    """
    Service Class

    allows to create new or access existing interprocess bridges.
    
    It enumerates at the servicemanager all services supporting the meta service com.sun.star.bridge.Bridge to get all known, possible protocols.

    See Also:
        `API BridgeFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1BridgeFactory.html>`_
    """


