# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class VclWindowPeerAttribute(object):
    """
    Const

    specifies attributes for the VCL window implementation.
    
    IMPORTANT: These constants have to be disjunct with constants in WindowAttribute.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API VclWindowPeerAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1VclWindowPeerAttribute.html>`_
    """
    HSCROLL: Literal[256]
    VSCROLL: Literal[512]
    LEFT: Literal[1024]
    CENTER: Literal[2048]
    RIGHT: Literal[4096]
    SPIN: Literal[8192]
    SORT: Literal[16384]
    DROPDOWN: Literal[32768]
    DEFBUTTON: Literal[65536]
    READONLY: Literal[262144]
    CLIPCHILDREN: Literal[524288]
    NOBORDER: Literal[1048576]
    GROUP: Literal[2097152]
    OK: Literal[4194304]
    OK_CANCEL: Literal[8388608]
    YES_NO: Literal[16777216]
    YES_NO_CANCEL: Literal[33554432]
    RETRY_CANCEL: Literal[67108864]
    DEF_OK: Literal[134217728]
    DEF_CANCEL: Literal[268435456]
    DEF_RETRY: Literal[536870912]
    DEF_YES: Literal[1073741824]
    DEF_NO: Literal[-2147483648]
    NOLABEL: Literal[536870912]
    AUTOHSCROLL: Literal[1073741824]
    AUTOVSCROLL: Literal[-2147483648]

