# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_input_stream import XInputStream as XInputStream_98d40ab4
from .x_markable_stream import XMarkableStream as XMarkableStream_b9bc0bc3

class MarkableInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XInputStream_98d40ab4, XMarkableStream_b9bc0bc3):
    """
    Service Class

    allows to set marks in an inputstream and to later jump back to these marks.
    
    The implementation reads the original data from the input stream, that has been set previously at the XActiveDataSink interface. In general the implementation must buffer the data.

    See Also:
        `API MarkableInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1MarkableInputStream.html>`_
    """


