# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal


class EmbedMapUnits(object):
    """
    Const

    contains list of possible map modes supported by embedded object.

    See Also:
        `API EmbedMapUnits <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedMapUnits.html>`_
    """
    ONE_100TH_MM: Literal[0]
    """
    In this type of map mode one logical point is equal to one-hundredth of millimeter.
    """
    ONE_10TH_MM: Literal[1]
    """
    In this type of map mode one logical point is equal to one-tenth of millimeter.
    """
    ONE_MM: Literal[2]
    """
    In this type of map mode one logical point is equal to one millimeter.
    """
    ONE_CM: Literal[3]
    """
    In this type of map mode one logical point is equal to one centimeter.
    """
    ONE_1000TH_INCH: Literal[4]
    """
    In this type of map mode one logical point is equal to one-thousandth of inch.
    """
    ONE_100TH_INCH: Literal[5]
    """
    In this type of map mode one logical point is equal to one-hundredth of inch.
    """
    ONE_10TH_INCH: Literal[6]
    """
    In this type of map mode one logical point is equal to one-tenth of inch.
    """
    ONE_INCH: Literal[7]
    """
    In this type of map mode one logical point is equal to one inch.
    """
    POINT: Literal[8]
    """
    In this type of map mode one logical point is equal to one typographical point.
    """
    TWIP: Literal[9]
    """
    In this type of map mode one logical point is equal to one twentieth of typographical point.
    """
    PIXEL: Literal[10]
    """
    In this type of map mode one logical point is equal to one pixel.
    """

