# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.3
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6


class theUICategoryDescription(XNameAccess_e2ab0cf6):
    """
    Singleton Class

    a singleton which provides information about user interface command categories.
    
    OpenOffice.org has an amount of commands that can be used by user interface elements. Every command is member of a single category. Categories makes it easier to handle to huge amount of commands provided by OpenOffice.org. This singleton is normally used by UI implementations which provides all commands to a user.
    
    Provides access to user interface command categories of the installed modules.
    
    To access the user interface command categories of a module, a unique module specifier must be provided to com.sun.star.container.XNameAccess.getByName() function. The module specifier can be retrieved from the com.sun.star.frame.ModuleManager service. The interface provides references to com.sun:star.ui.ModuleUICommandDescription.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) UICategoryDescription service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theUICategoryDescription <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1ui_1_1theUICategoryDescription.html>`_
    """


