# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from .uno_control_dialog_element import UnoControlDialogElement as UnoControlDialogElement_38ef0f81
from .x_control_model import XControlModel as XControlModel_affc0b7e
from ..beans.x_multi_property_set import XMultiPropertySet as XMultiPropertySet_fd880e05
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..io.x_persist_object import XPersistObject as XPersistObject_af2f0b79
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_cloneable import XCloneable as XCloneable_99d00aa3

class UnoControlModel(UnoControlDialogElement_38ef0f81, XControlModel_affc0b7e, XMultiPropertySet_fd880e05, XPropertySet_bc180bfa, XPersistObject_af2f0b79, XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    Service Class

    specifies the standard model of a UnoControl in the Smalltalk model view controller design.
    
    The interfaces com.sun.star.beans.XPropertySet and com.sun.star.beans.XMultiPropertySet need access to the model data from the embedding environment. The control and the model can specify additional interfaces to exchange data or export more functionality from the model.

    See Also:
        `API UnoControlModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlModel.html>`_
    """
    @property
    def DefaultControl(self) -> str:
        """
        specifies the service name of the default control for this model.
        """


