# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from typing_extensions import Literal
"""
Const

These enumeration values are used to specify the vertical orientation.

See Also:
    `API VertOrientation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html>`_
"""
NONE: Literal[0]
"""
no hard alignment
"""
TOP: Literal[1]
"""
aligned at the top
"""
CENTER: Literal[2]
"""
aligned at the center
"""
BOTTOM: Literal[3]
"""
aligned at the bottom
"""
CHAR_TOP: Literal[4]
"""
aligned at the top of a character (anchored to character)
"""
CHAR_CENTER: Literal[5]
"""
aligned at the center of a character (anchored to character )
"""
CHAR_BOTTOM: Literal[6]
"""
aligned at the bottom of a character (anchored to character )
"""
LINE_TOP: Literal[7]
"""
aligned at the top of the line (anchored to character )
"""
LINE_CENTER: Literal[8]
"""
aligned at the center of the line (anchored to character )
"""
LINE_BOTTOM: Literal[9]
"""
aligned at the bottom of the line (anchored to character )
"""

