# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_compound_type_description import XCompoundTypeDescription as XCompoundTypeDescription_c7be12f6
    from .x_parameter import XParameter as XParameter_e4470d2c

class XServiceConstructorDescription(ABC):
    """
    Reflects a service constructor.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XServiceConstructorDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XServiceConstructorDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XServiceConstructorDescription']

    def getExceptions(self) -> 'typing.Tuple[XCompoundTypeDescription_c7be12f6, ...]':
        """
        Returns the exceptions that can be raised by the constructor.
        """
    def getName(self) -> str:
        """
        Returns the constructor's name.
        """
    def getParameters(self) -> 'typing.Tuple[XParameter_e4470d2c, ...]':
        """
        Returns the constructor's parameters.
        """
    def isDefaultConstructor(self) -> bool:
        """
        Returns whether the constructor is a default constructor.
        """

