# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal


class TransitionType(object):
    """
    Const


    See Also:
        `API TransitionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionType.html>`_
    """
    BARWIPE: Literal[1]
    BOXWIPE: Literal[2]
    FOURBOXWIPE: Literal[3]
    BARNDOORWIPE: Literal[4]
    DIAGONALWIPE: Literal[5]
    BOWTIEWIPE: Literal[6]
    MISCDIAGONALWIPE: Literal[7]
    VEEWIPE: Literal[8]
    BARNVEEWIPE: Literal[9]
    ZIGZAGWIPE: Literal[10]
    BARNZIGZAGWIPE: Literal[11]
    IRISWIPE: Literal[12]
    TRIANGLEWIPE: Literal[13]
    ARROWHEADWIPE: Literal[14]
    PENTAGONWIPE: Literal[15]
    HEXAGONWIPE: Literal[16]
    ELLIPSEWIPE: Literal[17]
    EYEWIPE: Literal[18]
    ROUNDRECTWIPE: Literal[19]
    STARWIPE: Literal[20]
    MISCSHAPEWIPE: Literal[21]
    CLOCKWIPE: Literal[22]
    PINWHEELWIPE: Literal[23]
    SINGLESWEEPWIPE: Literal[24]
    FANWIPE: Literal[25]
    DOUBLEFANWIPE: Literal[26]
    DOUBLESWEEPWIPE: Literal[27]
    SALOONDOORWIPE: Literal[28]
    WINDSHIELDWIPE: Literal[29]
    SNAKEWIPE: Literal[30]
    SPIRALWIPE: Literal[31]
    PARALLELSNAKESWIPE: Literal[32]
    BOXSNAKESWIPE: Literal[33]
    WATERFALLWIPE: Literal[34]
    PUSHWIPE: Literal[35]
    SLIDEWIPE: Literal[36]
    FADE: Literal[37]
    RANDOMBARWIPE: Literal[38]
    CHECKERBOARDWIPE: Literal[39]
    DISSOLVE: Literal[40]
    BLINDSWIPE: Literal[41]
    RANDOM: Literal[42]
    ZOOM: Literal[43]

