# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.uno
from typing_extensions import Literal
from .x_interface import XInterface as XInterface_8f010a43

class XCurrentContext(XInterface_8f010a43):
    """
    Task (thread) local execution context for UNO.
    
    Arbitrary values can be retrieved from the context.
    
    You have to use UNO runtime functions to obtain the current context in your target language.

    See Also:
        `API XCurrentContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uno_1_1XCurrentContext.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.uno.XCurrentContext']

    def getValueByName(self, Name: str) -> object:
        """
        Gets a value from the context.
        """

