# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.linguistic2
from typing_extensions import Literal


class SpellFailure(object):
    """
    Const

    these define the various return types for spell checking to fail verification.
    
    A value of this type is part of the com.sun.star.linguistic2.XSpellAlternatives interface which is the return type for an unsuccessful spelling attempt.

    See Also:
        `API SpellFailure <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1SpellFailure.html>`_
    """
    IS_NEGATIVE_WORD: Literal[2]
    """
    The word is a negative one, that is, it should not be used.
    """
    CAPTION_ERROR: Literal[3]
    """
    The capitalization of the word is wrong.
    """
    SPELLING_ERROR: Literal[4]
    """
    The spelling of the word is wrong (or at least not known to be correct).
    """

