# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from .x_dispatch_provider import XDispatchProvider as XDispatchProvider_fc690de6
from .x_popup_menu_controller import XPopupMenuController as XPopupMenuController_29740f38
from .x_status_listener import XStatusListener as XStatusListener_e2740d35
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class PopupMenuController(XDispatchProvider_fc690de6, XPopupMenuController_29740f38, XStatusListener_e2740d35, XComponent_98dc0ab5, XInitialization_d46c0cca):
    """
    Service Class

    provides access to a pop-up menu controller.
    
    A pop-up menu controller is used to make special functions available to users, which depend on runtime or context specific conditions.
    A typical example for a pop-up menu controller can be a recent file list implementation which provides a list of latest files that a user has worked on. This list gets changes consistently during a work session.
    
    **since**
    
        OOo 2.0

    See Also:
        `API PopupMenuController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1PopupMenuController.html>`_
    """


