# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
from .x_frame_action_listener import XFrameActionListener as XFrameActionListener_26250efa
from .x_layout_manager import XLayoutManager as XLayoutManager_d4510ca4
from .x_layout_manager_event_broadcaster import XLayoutManagerEventBroadcaster as XLayoutManagerEventBroadcaster_d3f61310
from .x_menu_bar_merging_acceptor import XMenuBarMergingAcceptor as XMenuBarMergingAcceptor_53e5100f
from ..ui.xui_configuration_listener import XUIConfigurationListener as XUIConfigurationListener_34e90f7a

class XLayoutManager2(XFrameActionListener_26250efa, XLayoutManager_d4510ca4, XLayoutManagerEventBroadcaster_d3f61310, XMenuBarMergingAcceptor_53e5100f, XUIConfigurationListener_34e90f7a):
    """
    Unified interface for LayoutManager service.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API XLayoutManager2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XLayoutManager2']


