# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Offsets into the sequence of strings returned by XLocaleData.getReservedWord().

See Also:
    `API reservedWords <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1reservedWords.html>`_
"""
TRUE_WORD: Literal[0]
"""
\"true\"
"""
FALSE_WORD: Literal[1]
"""
\"false\"
"""
QUARTER1_WORD: Literal[2]
"""
\"1st quarter\"
"""
QUARTER2_WORD: Literal[3]
"""
\"2nd quarter\"
"""
QUARTER3_WORD: Literal[4]
"""
\"3rd quarter\"
"""
QUARTER4_WORD: Literal[5]
"""
\"4th quarter\"
"""
ABOVE_WORD: Literal[6]
"""
\"above\"
"""
BELOW_WORD: Literal[7]
"""
\"below\"
"""
QUARTER1_ABBREVIATION: Literal[8]
"""
\"Q1\"
"""
QUARTER2_ABBREVIATION: Literal[9]
"""
\"Q2\"
"""
QUARTER3_ABBREVIATION: Literal[10]
"""
\"Q3\"
"""
QUARTER4_ABBREVIATION: Literal[11]
"""
\"Q4\"
"""
COUNT: Literal[12]
"""
Yes, this must be the count of known reserved words and one more than the maximum number used above! Count of known reserved words.
"""

