# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XStringWidth(XInterface_8f010a43):
    """
    An interface that encapsulates the abstract notion of string width.

    See Also:
        `API XStringWidth <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XStringWidth.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XStringWidth']

    def queryStringWidth(self, aString: str) -> int:
        """
        compute the width of a given string.
        
        Depending on the implementation of this interface, the width of a string can be rather different things, like the number of characters in the string, or the width in pixel when displayed with a specific font.
        """

