# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Ambiguous(object):
    """
    Struct Class

    A value of a given type that can be ambiguous.
    
    This structure is used as the type of interface attributes corresponding to instances of com.sun.star.beans.Property that have the com.sun.star.beans.PropertyAttribute.MAYBEAMBIGUOUS.

    See Also:
        `API Ambiguous <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Ambiguous_3_01T_01_4.html>`_
    """
    typeName: Literal['com.sun.star.beans.Ambiguous']

    def __init__(self, Value: typing.Optional[object] = ..., IsAmbiguous: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Value (object, optional): Value value.
            IsAmbiguous (bool, optional): IsAmbiguous value.
        """


    @property
    def Value(self) -> object:
        """
        The underlying value of this structure instance.
        
        Even if this structure instance is ambiguous, this member should contain a useful value. If there is no useful value for an ambiguous structure instance, com.sun.star.beans.Optional can be used as the type of this member.
        """


    @property
    def IsAmbiguous(self) -> bool:
        """
        Marks this structure instance as ambiguous.
        """


