# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.registry
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API RegistryValueType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3>`_
"""

ASCII: 'uno.Enum'
"""
the type of the key is ASCII.
"""
ASCIILIST: 'uno.Enum'
"""
the type of the key is an ASCIILIST.
"""
BINARY: 'uno.Enum'
"""
the type of the key is binary.
"""
LONG: 'uno.Enum'
"""
the type of the key is long.
"""
LONGLIST: 'uno.Enum'
"""
the type of the key is LONGLIST.
"""
NOT_DEFINED: 'uno.Enum'
"""
the type of the key is not defined.
"""
STRING: 'uno.Enum'
"""
the type of the key is a string.
"""
STRINGLIST: 'uno.Enum'
"""
the type of the key is a STRINGLIST.
"""

