# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.xml.sax
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .input_source import InputSource as InputSource_c88c0c54

class XEntityResolver(XInterface_8f010a43):
    """
    makes it possible to modify the behavior of resolving external preferences.
    
    Usually, the parser has a default behavior of resolving external references (See documentation of the parser implementation). Use this interface to modify or reimplement this behavior.

    See Also:
        `API XEntityResolver <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XEntityResolver.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.sax.XEntityResolver']

    def resolveEntity(self, sPublicId: str, sSystemId: str) -> 'InputSource_c88c0c54':
        """
        If aInputStream is a valid reference to an input stream, the parser uses this InputSource. Otherwise the parser seeks for the entity using its default behavior.
        """

