# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.control
from ..submission.x_submission import XSubmission as XSubmission_3cfd0fba

class SubmitButton(XSubmission_3cfd0fba):
    """
    Service Class

    specifies a button control which can execute external submissions
    
    The model of the control has to support the com.sun.star.form.component.SubmitButton service.
    
    The control is clickable. When clicked (by mouse or keyboard, or programmatically), the following happens:

    See Also:
        `API SubmitButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1SubmitButton.html>`_
    """


