# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from .x_content_identifier_factory import XContentIdentifierFactory as XContentIdentifierFactory_56b91050
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0
from .x_parameterized_content_provider import XParameterizedContentProvider as XParameterizedContentProvider_9dc6120d

class RemoteProxyContentProvider(XContentIdentifierFactory_56b91050, XContentProvider_d4150cc0, XParameterizedContentProvider_9dc6120d):
    """
    Service Class

    A ContentProvider that wraps remote content providers that (potentially) have been distributed to a UCB.
    
    Before trying to pass a request to a \"real\", underlying content provider (which will most likely be a remote content provider distributed to this UCB), this proxy first activates any remote content providers that have been distributed here, but are still inactive (see RemoteContentProviderAcceptor and XRemoteContentProviderActivator for more information).
    
    The way this works might change, therefore this interface is marked as deprecated.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API RemoteProxyContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1RemoteProxyContentProvider.html>`_
    """


