# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
from ...awt.x_tab_controller_model import XTabControllerModel as XTabControllerModel_fbef0dd8
from ..form_component import FormComponent as FormComponent_bc700c03
from ..form_components import FormComponents as FormComponents_c8e60c76
from ..x_form import XForm as XForm_684408a8

class Form(FormComponent_bc700c03, FormComponents_c8e60c76, XTabControllerModel_fbef0dd8, XForm_684408a8):
    """
    Service Class

    This service specifies a form which is a group of FormComponents.
    
    A form fulfills several tasks, like storing the structure of its form components, storing the information concerning tab ordering and control grouping, and last but not least, it provides the event environment for its contained elements.
    
    A form acts on the one hand like a container of FormComponents and on the other hand like a FormComponent. This generic construction allows the definition of hierarchies of forms and their dependent subforms.

    See Also:
        `API Form <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1Form.html>`_
    """


