# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from ..lang.x_single_component_factory import XSingleComponentFactory as XSingleComponentFactory_46cc0fef

class WindowContentFactory(XSingleComponentFactory_46cc0fef):
    """
    Service Class

    specifies a factory which creates a window that is a container for user interface elements.
    
    Dependent on the provided arguments different window types can be created. This container window must be capable of being integrated into another window (e.g. docking or floating windows).
    
    The specific type of the created window depends on the provided arguments.
    
    **since**
    
        OOo 3.1

    See Also:
        `API WindowContentFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1WindowContentFactory.html>`_
    """


