# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from typing_extensions import Literal


class EnhancedCustomShapeSegmentCommand(object):
    """
    Const


    See Also:
        `API EnhancedCustomShapeSegmentCommand <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html>`_
    """
    UNKNOWN: Literal[0]
    MOVETO: Literal[1]
    LINETO: Literal[2]
    CURVETO: Literal[3]
    CLOSESUBPATH: Literal[4]
    ENDSUBPATH: Literal[5]
    NOFILL: Literal[6]
    NOSTROKE: Literal[7]
    ANGLEELLIPSETO: Literal[8]
    ANGLEELLIPSE: Literal[9]
    ARCTO: Literal[10]
    ARC: Literal[11]
    CLOCKWISEARCTO: Literal[12]
    CLOCKWISEARC: Literal[13]
    ELLIPTICALQUADRANTX: Literal[14]
    ELLIPTICALQUADRANTY: Literal[15]
    QUADRATICCURVETO: Literal[16]
    ARCANGLETO: Literal[17]
    DARKEN: Literal[18]
    """
    darken fill color
    """
    DARKENLESS: Literal[19]
    """
    darken fill color less
    """
    LIGHTEN: Literal[20]
    """
    lighten fill color
    """
    LIGHTENLESS: Literal[21]
    """
    lighten fill color less
    """

