# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API UnicodeScript <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29>`_
"""

kAlphabeticPresentation: 'uno.Enum'
"""
"""
kArabic: 'uno.Enum'
"""
"""
kArabicPresentationA: 'uno.Enum'
"""
"""
kArabicPresentationB: 'uno.Enum'
"""
"""
kArmenian: 'uno.Enum'
"""
"""
kArrow: 'uno.Enum'
"""
"""
kBasicLatin: 'uno.Enum'
"""
"""
kBengali: 'uno.Enum'
"""
"""
kBlockElement: 'uno.Enum'
"""
"""
kBopomofo: 'uno.Enum'
"""
"""
kBopomofoExtended: 'uno.Enum'
"""
"""
kBoxDrawing: 'uno.Enum'
"""
"""
kBraillePatterns: 'uno.Enum'
"""
"""
kCJKCompatibility: 'uno.Enum'
"""
"""
kCJKCompatibilityForm: 'uno.Enum'
"""
"""
kCJKCompatibilityIdeograph: 'uno.Enum'
"""
"""
kCJKRadicalsSupplement: 'uno.Enum'
"""
"""
kCJKSymbolPunctuation: 'uno.Enum'
"""
"""
kCJKUnifiedIdeograph: 'uno.Enum'
"""
"""
kCJKUnifiedIdeographsExtensionA: 'uno.Enum'
"""
"""
kCherokee: 'uno.Enum'
"""
"""
kCombiningDiacritical: 'uno.Enum'
"""
"""
kCombiningHalfMark: 'uno.Enum'
"""
"""
kControlPicture: 'uno.Enum'
"""
"""
kCurrencySymbolScript: 'uno.Enum'
"""
"""
kCyrillic: 'uno.Enum'
"""
"""
kDevanagari: 'uno.Enum'
"""
"""
kDingbat: 'uno.Enum'
"""
"""
kEnclosedAlphanumeric: 'uno.Enum'
"""
"""
kEnclosedCJKLetterMonth: 'uno.Enum'
"""
"""
kEthiopic: 'uno.Enum'
"""
"""
kGeneralPunctuation: 'uno.Enum'
"""
"""
kGeometricShape: 'uno.Enum'
"""
"""
kGeorgian: 'uno.Enum'
"""
"""
kGreek: 'uno.Enum'
"""
"""
kGreekExtended: 'uno.Enum'
"""
"""
kGujarati: 'uno.Enum'
"""
"""
kGurmukhi: 'uno.Enum'
"""
"""
kHalfwidthFullwidthForm: 'uno.Enum'
"""
"""
kHangulCompatibilityJamo: 'uno.Enum'
"""
"""
kHangulJamo: 'uno.Enum'
"""
"""
kHangulSyllable: 'uno.Enum'
"""
"""
kHebrew: 'uno.Enum'
"""
"""
kHighPrivateUseSurrogate: 'uno.Enum'
"""
"""
kHighSurrogate: 'uno.Enum'
"""
"""
kHiragana: 'uno.Enum'
"""
"""
kIPAExtension: 'uno.Enum'
"""
"""
kIdeographicDescriptionCharacters: 'uno.Enum'
"""
"""
kKanbun: 'uno.Enum'
"""
"""
kKangxiRadicals: 'uno.Enum'
"""
"""
kKannada: 'uno.Enum'
"""
"""
kKatakana: 'uno.Enum'
"""
"""
kKhmer: 'uno.Enum'
"""
"""
kLao: 'uno.Enum'
"""
"""
kLatin1Supplement: 'uno.Enum'
"""
"""
kLatinExtendedA: 'uno.Enum'
"""
"""
kLatinExtendedAdditional: 'uno.Enum'
"""
"""
kLatinExtendedB: 'uno.Enum'
"""
"""
kLetterlikeSymbol: 'uno.Enum'
"""
"""
kLowSurrogate: 'uno.Enum'
"""
"""
kMalayalam: 'uno.Enum'
"""
"""
kMathOperator: 'uno.Enum'
"""
"""
kMiscSymbol: 'uno.Enum'
"""
"""
kMiscTechnical: 'uno.Enum'
"""
"""
kMongolian: 'uno.Enum'
"""
"""
kMyanmar: 'uno.Enum'
"""
"""
kNoScript: 'uno.Enum'
"""
"""
kNumberForm: 'uno.Enum'
"""
"""
kOgham: 'uno.Enum'
"""
"""
kOpticalCharacter: 'uno.Enum'
"""
"""
kOriya: 'uno.Enum'
"""
"""
kPrivateUse: 'uno.Enum'
"""
"""
kRunic: 'uno.Enum'
"""
"""
kScriptCount: 'uno.Enum'
"""
"""
kSinhala: 'uno.Enum'
"""
"""
kSmallFormVariant: 'uno.Enum'
"""
"""
kSpacingModifier: 'uno.Enum'
"""
"""
kSuperSubScript: 'uno.Enum'
"""
"""
kSymbolCombiningMark: 'uno.Enum'
"""
"""
kSyriac: 'uno.Enum'
"""
"""
kTamil: 'uno.Enum'
"""
"""
kTelugu: 'uno.Enum'
"""
"""
kThaana: 'uno.Enum'
"""
"""
kThai: 'uno.Enum'
"""
"""
kTibetan: 'uno.Enum'
"""
"""
kUnifiedCanadianAboriginalSyllabics: 'uno.Enum'
"""
"""
kYiRadicals: 'uno.Enum'
"""
"""
kYiSyllables: 'uno.Enum'
"""
"""

