# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from .set_access import SetAccess as SetAccess_1ae0dfe
from .simple_set_update import SimpleSetUpdate as SimpleSetUpdate_5f4d1079

class SetUpdate(SetAccess_1ae0dfe, SimpleSetUpdate_5f4d1079):
    """
    Service Class

    provides write access to a dynamic homogeneous set of values or nested trees within a hierarchy.
    
    Allows adding and removing elements. Helps creates new elements to be added.
    
    This service extends SetAccess to support modifying the container.
    
    Any child and descendant objects support modifying access as well, unless they represent a read-only tree element (as indicated by com.sun.star.beans.PropertyAttribute.READONLY).

    See Also:
        `API SetUpdate <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SetUpdate.html>`_
    """


