# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the kind of strikeout.

They may be expanded in future versions.

See Also:
    `API FontStrikeout <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontStrikeout.html>`_
"""
NONE: Literal[0]
"""
specifies not to strike out the characters.
"""
SINGLE: Literal[1]
"""
specifies to strike out the characters with a single line.
"""
DOUBLE: Literal[2]
"""
specifies to strike out the characters with a double line.
"""
DONTKNOW: Literal[3]
"""
The strikeout mode is not specified.
"""
BOLD: Literal[4]
"""
specifies to strike out the characters with a bold line.
"""
SLASH: Literal[5]
"""
specifies to strike out the characters with slashes.
"""
X: Literal[6]
"""
specifies to strike out the characters with X's.
"""

