# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal


class UIElementType(object):
    """
    Const

    determine the type of a user interface element which is controlled by a layout manager.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UIElementType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1UIElementType.html>`_
    """
    UNKNOWN: Literal[0]
    """
    unknown user interface element type, which can be used as a wildcard to specify all types.
    """
    MENUBAR: Literal[1]
    """
    specifies a menu bar.
    """
    POPUPMENU: Literal[2]
    """
    specifies a pop-up menu.
    """
    TOOLBAR: Literal[3]
    """
    specifies a toolbar.
    """
    STATUSBAR: Literal[4]
    """
    specifies a statusbar.
    """
    FLOATINGWINDOW: Literal[5]
    """
    specifies a floating window, which can also be docked.
    """
    PROGRESSBAR: Literal[6]
    """
    specifies a floating window, which can also be docked.
    """
    TOOLPANEL: Literal[7]
    """
    specifies a tool panel
    """
    DOCKINGWINDOW: Literal[7]
    """
    specifies a window that can be docked.
    """
    COUNT: Literal[8]
    """
    specifies the number of constants.
    """

