# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

CTL script type constants for layout engine, returned by XScriptTypeDetector.getCTLScriptType()

**since**

    OOo 1.1.2

See Also:
    `API CTLScriptType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1CTLScriptType.html>`_
"""
CTL_UNKNOWN: Literal[0]
"""
For CTL scripts OOo currently does not support or could not handle.
"""
CTL_HEBREW: Literal[1]
"""
For Hebrew script.
"""
CTL_ARABIC: Literal[2]
"""
For Arabic script.
"""
CTL_THAI: Literal[3]
"""
For Thai script.
"""
CTL_INDIC: Literal[4]
"""
For Indic script (including Devanagari, Tamil, Telugu and Gujarati script)
"""

