# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
from abc import ABC

class XPublished(ABC):
    """
    Reflects the âpublishedâ status of a UNOIDL entity.
    
    This interface is intended to be supported by objects that also support com.sun.star.reflection.XTypeDescription. (This interface could have been made an optional sub-interface of com.sun.star.reflection.XTypeDescription, but is instead kept independent for reasons of backwards compatibility.)
    
    For the various kinds of UNOIDL entities that are represented by objects supporting com.sun.star.reflection.XTypeDescription and its subtypes, this optional interface should be supported as follows:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPublished <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XPublished.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XPublished']

    def isPublished(self) -> bool:
        """
        Returns the âpublishedâ status of a UNOIDL entity.
        """

