# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from typing_extensions import Literal


class SQLFilterOperator(object):
    """
    Const

    These constants are used to specify the filter operator which should be applied when creating a filter with the method XSingleSelectQueryComposer.setStructuredFilter().

    See Also:
        `API SQLFilterOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1SQLFilterOperator.html>`_
    """
    EQUAL: Literal[1]
    """
    equal to
    """
    NOT_EQUAL: Literal[2]
    """
    not equal to
    """
    LESS: Literal[3]
    """
    less than
    """
    GREATER: Literal[4]
    """
    greater than
    """
    LESS_EQUAL: Literal[5]
    """
    less or equal than
    """
    GREATER_EQUAL: Literal[6]
    """
    greater or equal than
    """
    LIKE: Literal[7]
    """
    like
    """
    NOT_LIKE: Literal[8]
    """
    not like
    """
    SQLNULL: Literal[9]
    """
    is null
    """
    NOT_SQLNULL: Literal[10]
    """
    is not null
    """

