# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class GeneralFunction(Enum):
    """
    Enum

    

    See Also:
        `API GeneralFunction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758d>`_
    """

    AUTO: 'uno.Enum'
    """
    specifies the use of a user-defined list.
    
    function is determined automatically.
    """
    AVERAGE: 'uno.Enum'
    """
    average of all numerical values is calculated.
    """
    COUNT: 'uno.Enum'
    """
    all values, including non-numerical values, are counted.
    """
    COUNTNUMS: 'uno.Enum'
    """
    numerical values are counted.
    """
    MAX: 'uno.Enum'
    """
    maximum value of all numerical values is calculated.
    """
    MIN: 'uno.Enum'
    """
    minimum value of all numerical values is calculated.
    """
    NONE: 'uno.Enum'
    """
    no cells are moved.
    
    sheet is not linked.
    
    new values are used without changes.
    
    nothing is calculated.
    
    nothing is imported.
    
    no condition is specified.
    """
    PRODUCT: 'uno.Enum'
    """
    product of all numerical values is calculated.
    """
    STDEV: 'uno.Enum'
    """
    standard deviation is calculated based on a sample.
    """
    STDEVP: 'uno.Enum'
    """
    standard deviation is calculated based on the entire population.
    """
    SUM: 'uno.Enum'
    """
    sum of all numerical values is calculated.
    """
    VAR: 'uno.Enum'
    """
    variance is calculated based on a sample.
    """
    VARP: 'uno.Enum'
    """
    variance is calculated based on the entire population.
    """

