# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.browse
# Libre Office Version: 7.3
from .x_browse_node_factory import XBrowseNodeFactory as XBrowseNodeFactory_8e541185


class theBrowseNodeFactory(XBrowseNodeFactory_8e541185):
    """
    Singleton Class

    The one and only BrowseNodeFactory.
    
    To get the singleton call getValueByName on the component context
    
    **since**
    
        OOo 2.0

    See Also:
        `API theBrowseNodeFactory <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1script_1_1browse_1_1theBrowseNodeFactory.html>`_
    """


