# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
import typing
from ...awt.uno_control_list_box_model import UnoControlListBoxModel as UnoControlListBoxModel_2a3c0f1d
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_reset import XReset as XReset_71670917

class ListBox(UnoControlListBoxModel_2a3c0f1d, FormControlModel_e2990d22, XReset_71670917):
    """
    Service Class

    specifies a model for a control which allows to choose in a list of alternative values.

    See Also:
        `API ListBox <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1ListBox.html>`_
    """
    @property
    def DefaultSelection(self) -> 'typing.Tuple[int, ...]':
        """
        contains the indexes of entries of the listbox, which should selected by default.
        
        This selection is used initially or for a reset.
        """
    @property
    def ListSource(self) -> 'typing.Tuple[str, ...]':
        """
        contains the values associated to the strings to be displayed (which are specified by com.sun.star.awt.UnoControlListBoxModel.StringItemList)
        """


