# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .data_pilot_field_filter import DataPilotFieldFilter as DataPilotFieldFilter_271e0eed

class XDrillDownDataSupplier(XInterface_8f010a43):
    """
    supplies a filtered subset of the original data source based on filtering criteria.
    
    A service that acts as a DataPilot data source can optionally implement this interface to allow drill-down of result data. The method this interface provides is used internally when calling XDataPilotTable2.getDrillDownData() or XDataPilotTable2.insertDrillDownSheet(). If the data source service does not implement this interface, then the aforementioned two methods will have no effect.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XDrillDownDataSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDrillDownDataSupplier.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XDrillDownDataSupplier']

    def getDrillDownData(self, aFilters: 'typing.Tuple[DataPilotFieldFilter_271e0eed, ...]') -> 'typing.Tuple[typing.Tuple[object, ...], ...]':
        """
        This method returns filtered subset of the original source data based on a given set of filtering criteria.
        """

