# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class Months(object):
    """
    Const

    Constants for month names used in calls to XCalendar.getDisplayName().

    See Also:
        `API Months <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html>`_
    """
    JANUARY: Literal[0]
    """
    January.
    """
    FEBURARY: Literal[1]
    """
    February.
    """
    MARCH: Literal[2]
    """
    March.
    """
    APRIL: Literal[3]
    """
    April.
    """
    MAY: Literal[4]
    """
    May.
    """
    JUNE: Literal[5]
    """
    June.
    """
    JULY: Literal[6]
    """
    July.
    """
    AUGUST: Literal[7]
    """
    August.
    """
    SEPTEMBER: Literal[8]
    """
    September.
    """
    OCTOBER: Literal[9]
    """
    October.
    """
    NOVEMBER: Literal[10]
    """
    November.
    """
    DECEMBER: Literal[11]
    """
    December.
    """

