# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from .x_shapes import XShapes as XShapes_9a800ab0

class ShapeCollection(XShapes_9a800ab0):
    """
    Service Class

    This service describes a generic container to manage collections of Shape.
    
    The Shape that are added to this collection are not owned by the collection.
    
    This service is used by the view f.e. to return a collection of Shape that are selected at the ui.

    See Also:
        `API ShapeCollection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1ShapeCollection.html>`_
    """


