# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class Error(object):
    """
    Const

    These codes are used to indicate errors.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API Error <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1Error.html>`_
    """
    NONE: Literal[0]
    LOGIN_FAILURE_RECEIVE: Literal[122880]
    LOGIN_FAILURE_NEWSSEND: Literal[122881]
    LOGIN_FAILURE_MAILSEND: Literal[122882]
    CONNECT_FAILURE: Literal[122883]
    UCB_OFFLINE: Literal[122884]
    UCB_SERVER_ERROR: Literal[122885]
    STORAGE_READONLY: Literal[122886]
    STORAGE_KILLED: Literal[122887]
    WRONG_FILE_FORMAT: Literal[122888]
    UNSUPPORTED_URL: Literal[122889]
    CNTOUT_NO_FROM: Literal[122890]
    TOO_MANY_GROUPS: Literal[122891]
    DELETE_ABORTED: Literal[122892]
    QUERY_DELETE: Literal[122893]
    NOTAVAILABLE: Literal[122894]
    VIM_LIBRARY_ERROR: Literal[122895]
    FOLDER_INVALID: Literal[122896]
    FTP_RESOLVERERROR: Literal[122897]
    FTP_NETWORKERROR: Literal[122898]
    FTP_NOTNECESSARYCMD: Literal[122899]
    FTP_SERVICEUNAVAILABLE: Literal[122900]
    FTP_DCONFAILURE: Literal[122901]
    FTP_TRANSFERABORTED: Literal[122902]
    NO_VIM_LIBRARY: Literal[122903]
    VIM_LIBRARY_CORRUPTED: Literal[122904]
    CCMAIL_EXPORT_ERROR: Literal[122905]
    NO_CCMAIL_EXPORT_FILE: Literal[122906]
    ILLEGAL_CCMAIL_EXPORT_FILE: Literal[122907]
    MESSAGE_NOT_FOUND: Literal[122908]
    BAD_CCMAIL_EXPORT_PASSWORD: Literal[122909]
    CCMAIL_EXPORT_TOO_LONG: Literal[122910]
    FOLDER_EXISTS: Literal[122911]
    FOLDER_NOT_EXISTS: Literal[122912]
    NO_VIM_BBOARDLIST: Literal[122913]
    ILLEGAL_MESSAGE_ID: Literal[122914]
    SERVER_PORT_SYNTAX: Literal[122915]
    SERVERNAME_SYNTAX: Literal[122916]
    USERNAME_SYNTAX: Literal[122917]
    IS_RESCHEDULED: Literal[122918]
    VIM_NO_FAKE_MESSAGE_ID: Literal[122919]
    FSYS_ROOT_DELETE: Literal[122920]
    FILE_EXISTS: Literal[122921]
    FILE_NOT_EXISTS: Literal[122922]
    FSYS_MISPLACED_CHAR: Literal[122923]
    FSYS_INVALID_CHAR: Literal[122924]
    FSYS_INVALID_DEVICE: Literal[122925]
    FSYS_ACCESS_DENIED: Literal[122926]
    FSYS_LOCK_VIOLATION: Literal[122927]
    FSYS_VOLUME_FULL: Literal[122928]
    FSYS_NOT_SUPPORTED: Literal[122929]
    FSYS_UNKNOWN: Literal[122930]
    FSYS_NOT_A_FILE: Literal[122931]
    FSYS_NOT_A_DIRECTORY: Literal[122932]
    FSYS_IS_WILDCARD: Literal[122933]
    RENAMED_WRONG_FILE_FORMAT: Literal[122934]
    FSYS_UPDATE_NEEDED: Literal[122935]
    FSYS_CANT_RESOLVE_CONFLICT: Literal[122936]
    FSYS_CANT_ITERATE: Literal[122937]
    ONE_NOT_SEARCHABLE: Literal[122938]
    MULTIPLE_NOT_SEARCHABLE: Literal[122939]
    FSYS_CACHE_INCONSISTENT: Literal[122940]
    FSYS_READONLY: Literal[122941]
    FSYS_LOCK: Literal[122942]
    FSYS_UNLOCK: Literal[122943]
    FSYS_DELETE: Literal[122944]
    FSYS_IS_MARKED: Literal[122945]
    FTP_GENERAL_FAILURE: Literal[122946]
    DO_LOG: Literal[122947]
    HTTP_COOKIE_REQUEST: Literal[122948]
    FSYS_LOST_ROOT: Literal[122949]
    FTP_PROXY: Literal[122950]
    SOURCE_SAME_AS_TARGET: Literal[122951]
    CONFIRM_EMPTY_TRASH: Literal[122952]
    FSYS_NO_TARGET: Literal[122953]
    FSYS_RECURSIVE: Literal[122954]
    FSYS_INSERT_MEDIUM: Literal[122955]
    NO_DOCINFO: Literal[122956]
    CCMAIL_EXPORT_NOT_TERMINATING: Literal[122957]
    EXTERNAL_COMMAND_FAILED: Literal[122958]
    RENAME_FAILED: Literal[122959]
    NOT_HANDLED: Literal[122960]
    COULD_NOT_INIT_COMPONENT: Literal[122961]
    TRANSFER_URL_NOT_SUPPORTED: Literal[122962]
    EMPTY_SERVERNAME: Literal[122963]
    EMPTY_USERNAME: Literal[122964]
    BAD_INET: Literal[122965]
    IMAP_SERVER_MSG: Literal[122966]
    IMAP_CONNECTION_CLOSED: Literal[122967]
    IMAP_NOT_IMAP4: Literal[122968]
    IMAP_BAD_SERVER: Literal[122969]
    REORGANIZE_FILE_LOCKED: Literal[122970]
    IMAP_BAD_TITLE: Literal[122971]
    SERVER_CONNECT_FAILURE: Literal[122972]
    PASSWORD_SYNTAX: Literal[122973]
    QUERY_DELETE_CACHE: Literal[122974]
    REORGANIZE_NO_DISKSPACE: Literal[122975]
    LOGIN_FAILURE_ACCOUNT: Literal[122976]
    ACCOUNT_SYNTAX: Literal[122977]

