# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class ModuleWindowStateConfiguration(XNameContainer_cb90e47):
    """
    Service Class

    a service which provides window based information about user interface elements of a single application module.
    
    Every OpenOffice.org module has an amount of user interface elements that can be positioned, resized, closed and their style can be changed. This service provides access to the window based information of available user interface elements which are part of a single OpenOffice.org module, like Writer or Calc.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ModuleWindowStateConfiguration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ModuleWindowStateConfiguration.html>`_
    """


