# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from .macro_expander import MacroExpander as MacroExpander_bca00bef

class BootstrapMacroExpander(MacroExpander_bca00bef, XInitialization_d46c0cca):
    """
    Service Class

    Macro expander expanding using rtl bootstrap notation.
    
    For details, have a look at http://udk.openoffice.org/common/man/concept/micro_deployment.html#misc
    
    The service can be instantiated via arguments giving an ini/rc file url. Otherwise it will read from a uno.ini/unorc file next to the cppuhelper library.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API BootstrapMacroExpander <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1BootstrapMacroExpander.html>`_
    """


