# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class Key(object):
    """
    Const

    These values are used to specify distinct physical keys, plus some special values used by the macOS implementation.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API Key <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html>`_
    """
    NUM0: Literal[256]
    NUM1: Literal[257]
    NUM2: Literal[258]
    NUM3: Literal[259]
    NUM4: Literal[260]
    NUM5: Literal[261]
    NUM6: Literal[262]
    NUM7: Literal[263]
    NUM8: Literal[264]
    NUM9: Literal[265]
    A: Literal[512]
    B: Literal[513]
    C: Literal[514]
    D: Literal[515]
    E: Literal[516]
    F: Literal[517]
    G: Literal[518]
    H: Literal[519]
    I: Literal[520]
    J: Literal[521]
    K: Literal[522]
    L: Literal[523]
    M: Literal[524]
    N: Literal[525]
    O: Literal[526]
    P: Literal[527]
    Q: Literal[528]
    R: Literal[529]
    S: Literal[530]
    T: Literal[531]
    U: Literal[532]
    V: Literal[533]
    W: Literal[534]
    X: Literal[535]
    Y: Literal[536]
    Z: Literal[537]
    F1: Literal[768]
    F2: Literal[769]
    F3: Literal[770]
    F4: Literal[771]
    F5: Literal[772]
    F6: Literal[773]
    F7: Literal[774]
    F8: Literal[775]
    F9: Literal[776]
    F10: Literal[777]
    F11: Literal[778]
    F12: Literal[779]
    F13: Literal[780]
    F14: Literal[781]
    F15: Literal[782]
    F16: Literal[783]
    F17: Literal[784]
    F18: Literal[785]
    F19: Literal[786]
    F20: Literal[787]
    F21: Literal[788]
    F22: Literal[789]
    F23: Literal[790]
    F24: Literal[791]
    F25: Literal[792]
    F26: Literal[793]
    DOWN: Literal[1024]
    UP: Literal[1025]
    LEFT: Literal[1026]
    RIGHT: Literal[1027]
    HOME: Literal[1028]
    END: Literal[1029]
    PAGEUP: Literal[1030]
    PAGEDOWN: Literal[1031]
    RETURN: Literal[1280]
    ESCAPE: Literal[1281]
    TAB: Literal[1282]
    BACKSPACE: Literal[1283]
    SPACE: Literal[1284]
    INSERT: Literal[1285]
    DELETE: Literal[1286]
    ADD: Literal[1287]
    SUBTRACT: Literal[1288]
    MULTIPLY: Literal[1289]
    DIVIDE: Literal[1290]
    POINT: Literal[1291]
    COMMA: Literal[1292]
    LESS: Literal[1293]
    GREATER: Literal[1294]
    EQUAL: Literal[1295]
    OPEN: Literal[1296]
    CUT: Literal[1297]
    COPY: Literal[1298]
    PASTE: Literal[1299]
    UNDO: Literal[1300]
    REPEAT: Literal[1301]
    FIND: Literal[1302]
    PROPERTIES: Literal[1303]
    FRONT: Literal[1304]
    CONTEXTMENU: Literal[1305]
    HELP: Literal[1306]
    MENU: Literal[1307]
    HANGUL_HANJA: Literal[1308]
    DECIMAL: Literal[1309]
    TILDE: Literal[1310]
    QUOTELEFT: Literal[1311]
    CAPSLOCK: Literal[1312]
    NUMLOCK: Literal[1313]
    SCROLLLOCK: Literal[1314]
    DELETE_TO_BEGIN_OF_LINE: Literal[1536]
    DELETE_TO_END_OF_LINE: Literal[1537]
    DELETE_TO_BEGIN_OF_PARAGRAPH: Literal[1538]
    BRACKETLEFT: Literal[1315]
    BRACKETRIGHT: Literal[1316]
    SEMICOLON: Literal[1317]
    QUOTERIGHT: Literal[1318]
    DELETE_TO_END_OF_PARAGRAPH: Literal[1539]
    """
    The following values don't correspond to physical keys on any keyboard but are used in the macOS implementation of VCL.
    
    They correspond to some of the action messages of the NSResponder abstract class.
    """
    DELETE_WORD_BACKWARD: Literal[1540]
    DELETE_WORD_FORWARD: Literal[1541]
    INSERT_LINEBREAK: Literal[1542]
    INSERT_PARAGRAPH: Literal[1543]
    MOVE_WORD_BACKWARD: Literal[1544]
    MOVE_WORD_FORWARD: Literal[1545]
    MOVE_TO_BEGIN_OF_LINE: Literal[1546]
    MOVE_TO_END_OF_LINE: Literal[1547]
    MOVE_TO_BEGIN_OF_PARAGRAPH: Literal[1548]
    MOVE_TO_END_OF_PARAGRAPH: Literal[1549]
    SELECT_BACKWARD: Literal[1550]
    SELECT_FORWARD: Literal[1551]
    SELECT_WORD_BACKWARD: Literal[1552]
    SELECT_WORD_FORWARD: Literal[1553]
    SELECT_WORD: Literal[1554]
    SELECT_LINE: Literal[1555]
    SELECT_PARAGRAPH: Literal[1556]
    SELECT_ALL: Literal[1557]
    SELECT_TO_BEGIN_OF_LINE: Literal[1558]
    SELECT_TO_END_OF_LINE: Literal[1559]
    MOVE_TO_BEGIN_OF_DOCUMENT: Literal[1560]
    MOVE_TO_END_OF_DOCUMENT: Literal[1561]
    SELECT_TO_BEGIN_OF_DOCUMENT: Literal[1562]
    SELECT_TO_END_OF_DOCUMENT: Literal[1563]
    SELECT_TO_BEGIN_OF_PARAGRAPH: Literal[1564]
    SELECT_TO_END_OF_PARAGRAPH: Literal[1565]

