# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTimeStamped(XInterface_8f010a43):
    """
    provides timestamp information for an object in the form of an arbitrary string.
    
    The format and meaning of the timestamp depends on the implementation. Services implementing this interface must document the meaning and format they use.
    
    If the timestamp is unchanged between two calls, the associated object has not changed. Any properties beyond this, particularly the presence of a meaningful order between timestamps, depend on the implementation.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XTimeStamped <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XTimeStamped.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XTimeStamped']

    def getTimestamp(self) -> str:
        """
        returns the timestamp of the object.
        """

