# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
"""
Const

Constants to specify some well-known URIs.

These constants are for use with URI.createKnown().

**since**

    OOo 3.2

See Also:
    `API URIs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1URIs.html>`_
"""
XSD_NCNAME: Literal[1]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NCName
"""
XSD_STRING: Literal[2]
"""
http://www.w3.org/2001/XMLSchema-datatypes#string
"""
XSD_NORMALIZEDSTRING: Literal[3]
"""
http://www.w3.org/2001/XMLSchema-datatypes#normalizedString
"""
XSD_BOOLEAN: Literal[4]
"""
http://www.w3.org/2001/XMLSchema-datatypes#boolean
"""
XSD_DECIMAL: Literal[5]
"""
http://www.w3.org/2001/XMLSchema-datatypes#decimal
"""
XSD_FLOAT: Literal[6]
"""
http://www.w3.org/2001/XMLSchema-datatypes#float
"""
XSD_DOUBLE: Literal[7]
"""
http://www.w3.org/2001/XMLSchema-datatypes#double
"""
XSD_INTEGER: Literal[8]
"""
http://www.w3.org/2001/XMLSchema-datatypes#integer
"""
XSD_NONNEGATIVEINTEGER: Literal[9]
"""
http://www.w3.org/2001/XMLSchema-datatypes#nonNegativeInteger
"""
XSD_POSITIVEINTEGER: Literal[10]
"""
http://www.w3.org/2001/XMLSchema-datatypes#positiveInteger
"""
XSD_NONPOSITIVEINTEGER: Literal[11]
"""
http://www.w3.org/2001/XMLSchema-datatypes#nonPositiveInteger
"""
XSD_NEGATIVEINTEGER: Literal[12]
"""
http://www.w3.org/2001/XMLSchema-datatypes#negativeInteger
"""
XSD_LONG: Literal[13]
"""
http://www.w3.org/2001/XMLSchema-datatypes#long
"""
XSD_INT: Literal[14]
"""
http://www.w3.org/2001/XMLSchema-datatypes#int
"""
XSD_SHORT: Literal[15]
"""
http://www.w3.org/2001/XMLSchema-datatypes#short
"""
XSD_BYTE: Literal[16]
"""
http://www.w3.org/2001/XMLSchema-datatypes#byte
"""
XSD_UNSIGNEDLONG: Literal[17]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedLong
"""
XSD_UNSIGNEDINT: Literal[18]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedInt
"""
XSD_UNSIGNEDSHORT: Literal[19]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedShort
"""
XSD_UNSIGNEDBYTE: Literal[20]
"""
http://www.w3.org/2001/XMLSchema-datatypes#unsignedByte
"""
XSD_HEXBINARY: Literal[21]
"""
http://www.w3.org/2001/XMLSchema-datatypes#hexBinary
"""
XSD_BASE64BINARY: Literal[22]
"""
http://www.w3.org/2001/XMLSchema-datatypes#base64Binary
"""
XSD_DATETIME: Literal[23]
"""
http://www.w3.org/2001/XMLSchema-datatypes#dateTime
"""
XSD_TIME: Literal[24]
"""
http://www.w3.org/2001/XMLSchema-datatypes#time
"""
XSD_DATE: Literal[25]
"""
http://www.w3.org/2001/XMLSchema-datatypes#date
"""
XSD_GYEARMONTH: Literal[26]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gYearMonth
"""
XSD_GYEAR: Literal[27]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gYear
"""
XSD_GMONTHDAY: Literal[28]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gMonthDay
"""
XSD_GDAY: Literal[29]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gDay
"""
XSD_GMONTH: Literal[30]
"""
http://www.w3.org/2001/XMLSchema-datatypes#gMonth
"""
XSD_ANYURI: Literal[31]
"""
http://www.w3.org/2001/XMLSchema-datatypes#anyURI
"""
XSD_TOKEN: Literal[32]
"""
http://www.w3.org/2001/XMLSchema-datatypes#token
"""
XSD_LANGUAGE: Literal[33]
"""
http://www.w3.org/2001/XMLSchema-datatypes#language
"""
XSD_NMTOKEN: Literal[34]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NMTOKEN
"""
XSD_NAME: Literal[35]
"""
http://www.w3.org/2001/XMLSchema-datatypes#Name
"""
XSD_DURATION: Literal[36]
"""
http://www.w3.org/2001/XMLSchema-datatypes#duration
"""
XSD_QNAME: Literal[37]
"""
http://www.w3.org/2001/XMLSchema-datatypes#QName
"""
XSD_NOTATION: Literal[38]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NOTATION
"""
XSD_NMTOKENS: Literal[39]
"""
http://www.w3.org/2001/XMLSchema-datatypes#NMTOKENS
"""
XSD_ID: Literal[40]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ID
"""
XSD_IDREF: Literal[41]
"""
http://www.w3.org/2001/XMLSchema-datatypes#IDREF
"""
XSD_IDREFS: Literal[42]
"""
http://www.w3.org/2001/XMLSchema-datatypes#IDREFS
"""
XSD_ENTITY: Literal[43]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ENTITY
"""
XSD_ENTITIES: Literal[44]
"""
http://www.w3.org/2001/XMLSchema-datatypes#ENTITIES
"""
RDF_TYPE: Literal[1000]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#type
"""
RDF_SUBJECT: Literal[1001]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#subject
"""
RDF_PREDICATE: Literal[1002]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate
"""
RDF_OBJECT: Literal[1003]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#object
"""
RDF_PROPERTY: Literal[1004]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Property
"""
RDF_STATEMENT: Literal[1005]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement
"""
RDF_VALUE: Literal[1006]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#value
"""
RDF_FIRST: Literal[1007]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#first
"""
RDF_REST: Literal[1008]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#rest
"""
RDF_NIL: Literal[1009]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#nil
"""
RDF_XMLLITERAL: Literal[1010]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral
"""
RDF_ALT: Literal[1011]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt
"""
RDF_BAG: Literal[1012]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag
"""
RDF_LIST: Literal[1013]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#List
"""
RDF_SEQ: Literal[1014]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq
"""
RDF_1: Literal[1015]
"""
http://www.w3.org/1999/02/22-rdf-syntax-ns#_1
"""
RDFS_COMMENT: Literal[1100]
"""
http://www.w3.org/2000/01/rdf-schema#comment
"""
RDFS_LABEL: Literal[1101]
"""
http://www.w3.org/2000/01/rdf-schema#label
"""
RDFS_DOMAIN: Literal[1102]
"""
http://www.w3.org/2000/01/rdf-schema#domain
"""
RDFS_RANGE: Literal[1103]
"""
http://www.w3.org/2000/01/rdf-schema#range
"""
RDFS_SUBCLASSOF: Literal[1104]
"""
http://www.w3.org/2000/01/rdf-schema#subClassOf
"""
RDFS_LITERAL: Literal[1105]
"""
http://www.w3.org/2000/01/rdf-schema#Literal
"""
RDFS_MEMBER: Literal[1106]
"""
http://www.w3.org/2000/01/rdf-schema#member
"""
RDFS_SUBPROPERTYOF: Literal[1107]
"""
http://www.w3.org/2000/01/rdf-schema#subPropertyOf
"""
RDFS_ISDEFINEDBY: Literal[1108]
"""
http://www.w3.org/2000/01/rdf-schema#isDefinedBy
"""
RDFS_SEEALSO: Literal[1109]
"""
http://www.w3.org/2000/01/rdf-schema#seeAlso
"""
RDFS_RESOURCE: Literal[1110]
"""
http://www.w3.org/2000/01/rdf-schema#Resource
"""
RDFS_CLASS: Literal[1111]
"""
http://www.w3.org/2000/01/rdf-schema#Class
"""
RDFS_DATATYPE: Literal[1112]
"""
http://www.w3.org/2000/01/rdf-schema#Datatype
"""
RDFS_CONTAINER: Literal[1113]
"""
http://www.w3.org/2000/01/rdf-schema#Container
"""
RDFS_CONTAINERMEMBERSHIPPROPERTY: Literal[1114]
"""
http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty
"""
OWL_CLASS: Literal[1200]
"""
http://www.w3.org/2002/07/owl#Class
"""
OWL_OBJECTPROPERTY: Literal[1201]
"""
http://www.w3.org/2002/07/owl#ObjectProperty
"""
OWL_DATATYPEPROPERTY: Literal[1202]
"""
http://www.w3.org/2002/07/owl#DatatypeProperty
"""
OWL_FUNCTIONALPROPERTY: Literal[1203]
"""
http://www.w3.org/2002/07/owl#FunctionalProperty
"""
OWL_THING: Literal[1204]
"""
http://www.w3.org/2002/07/owl#Thing
"""
OWL_NOTHING: Literal[1205]
"""
http://www.w3.org/2002/07/owl#Nothing
"""
OWL_INDIVIDUAL: Literal[1206]
"""
http://www.w3.org/2002/07/owl#Individual
"""
OWL_EQUIVALENTCLASS: Literal[1207]
"""
http://www.w3.org/2002/07/owl#equivalentClass
"""
OWL_EQUIVALENTPROPERTY: Literal[1208]
"""
http://www.w3.org/2002/07/owl#equivalentProperty
"""
OWL_SAMEAS: Literal[1209]
"""
http://www.w3.org/2002/07/owl#sameAs
"""
OWL_DIFFERENTFROM: Literal[1210]
"""
http://www.w3.org/2002/07/owl#differentFrom
"""
OWL_ALLDIFFERENT: Literal[1211]
"""
http://www.w3.org/2002/07/owl#AllDifferent
"""
OWL_DISTINCTMEMBERS: Literal[1212]
"""
http://www.w3.org/2002/07/owl#distinctMembers
"""
OWL_INVERSEOF: Literal[1213]
"""
http://www.w3.org/2002/07/owl#inverseOf
"""
OWL_TRANSITIVEPROPERTY: Literal[1214]
"""
http://www.w3.org/2002/07/owl#TransitiveProperty
"""
OWL_SYMMETRICPROPERTY: Literal[1215]
"""
http://www.w3.org/2002/07/owl#SymmetricProperty
"""
OWL_INVERSEFUNCTIONALPROPERTY: Literal[1216]
"""
http://www.w3.org/2002/07/owl#InverseFunctionalProperty
"""
OWL_RESTRICTION: Literal[1217]
"""
http://www.w3.org/2002/07/owl#Restriction
"""
OWL_ONPROPERTY: Literal[1218]
"""
http://www.w3.org/2002/07/owl#onProperty
"""
OWL_ALLVALUESFROM: Literal[1219]
"""
http://www.w3.org/2002/07/owl#allValuesFrom
"""
OWL_SOMEVALUESFROM: Literal[1220]
"""
http://www.w3.org/2002/07/owl#someValuesFrom
"""
OWL_MINCARDINALITY: Literal[1221]
"""
http://www.w3.org/2002/07/owl#minCardinality
"""
OWL_MAXCARDINALITY: Literal[1222]
"""
http://www.w3.org/2002/07/owl#maxCardinality
"""
OWL_CARDINALITY: Literal[1223]
"""
http://www.w3.org/2002/07/owl#cardinality
"""
OWL_ONTOLOGY: Literal[1224]
"""
http://www.w3.org/2002/07/owl#Ontology
"""
OWL_IMPORTS: Literal[1225]
"""
http://www.w3.org/2002/07/owl#imports
"""
OWL_VERSIONINFO: Literal[1226]
"""
http://www.w3.org/2002/07/owl#versionInfo
"""
OWL_PRIORVERSION: Literal[1227]
"""
http://www.w3.org/2002/07/owl#priorVersion
"""
OWL_BACKWARDCOMPATIBLEWITH: Literal[1228]
"""
http://www.w3.org/2002/07/owl#backwardCompatibleWith
"""
OWL_INCOMPATIBLEWITH: Literal[1229]
"""
http://www.w3.org/2002/07/owl#incompatibleWith
"""
OWL_DEPRECATEDCLASS: Literal[1230]
"""
http://www.w3.org/2002/07/owl#DeprecatedClass
"""
OWL_DEPRECATEDPROPERTY: Literal[1231]
"""
http://www.w3.org/2002/07/owl#DeprecatedProperty
"""
OWL_ANNOTATIONPROPERTY: Literal[1232]
"""
http://www.w3.org/2002/07/owl#AnnotationProperty
"""
OWL_ONTOLOGYPROPERTY: Literal[1233]
"""
http://www.w3.org/2002/07/owl#OntologyProperty
"""
OWL_ONEOF: Literal[1234]
"""
http://www.w3.org/2002/07/owl#oneOf
"""
OWL_DATARANGE: Literal[1235]
"""
http://www.w3.org/2002/07/owl#dataRange
"""
OWL_DISJOINTWITH: Literal[1236]
"""
http://www.w3.org/2002/07/owl#disjointWith
"""
OWL_UNIONOF: Literal[1237]
"""
http://www.w3.org/2002/07/owl#unionOf
"""
OWL_COMPLEMENTOF: Literal[1238]
"""
http://www.w3.org/2002/07/owl#complementOf
"""
OWL_INTERSECTIONOF: Literal[1239]
"""
http://www.w3.org/2002/07/owl#intersectionOf
"""
OWL_HASVALUE: Literal[1240]
"""
http://www.w3.org/2002/07/owl#hasValue
"""
PKG_HASPART: Literal[2000]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#hasPart
"""
PKG_MIMETYPE: Literal[2003]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#mimeType
"""
PKG_PACKAGE: Literal[2004]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Package
"""
PKG_ELEMENT: Literal[2005]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Element
"""
PKG_FILE: Literal[2006]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#File
"""
PKG_METADATAFILE: Literal[2007]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#MetadataFile
"""
PKG_DOCUMENT: Literal[2008]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Document
"""
ODF_PREFIX: Literal[2100]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#prefix
"""
ODF_SUFFIX: Literal[2101]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#suffix
"""
ODF_ELEMENT: Literal[2102]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#Element
"""
ODF_CONTENTFILE: Literal[2103]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#ContentFile
"""
ODF_STYLESFILE: Literal[2104]
"""
http://docs.oasis-open.org/ns/office/1.2/meta/odf#StylesFile
"""
LO_EXT_SHADING: Literal[2106]
"""
custom shading color of an annotated text range or metadata field (replacement of the default field shading color)

urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0odf#shading

**since**

    LibreOffice 7.2
"""

