# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.embed
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XActionsApproval(XInterface_8f010a43):
    """
    allows to request an approval for an action.
    
    An implementation of this interface is usually provided to another object to allow this object to request an approval for actions. The list of possible actions must be documented in documentation of the object.

    See Also:
        `API XActionsApproval <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XActionsApproval.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.embed.XActionsApproval']

    def approveAction(self, nAction: int) -> bool:
        """
        requests an approval for the specified action.
        """

