# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration.bootstrap
from ...uno.x_component_context import XComponentContext as XComponentContext_e2e10d4a

class BootstrapContext(XComponentContext_e2e10d4a):
    """
    Service Class

    provides access to a component context that is enhanced with bootstrap parameters for configuration services from the associated metaconfiguration mechanism.
    
    The contained settings are used to initialize the com.sun.star.configuration.DefaultProvider and com.sun.star.configuration.backend.DefaultBackend of the component context.
    
    The implementation is usually available as a singleton in the context that it wraps...
    
    **since**
    
        OOo 1.1.2
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API BootstrapContext <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1bootstrap_1_1BootstrapContext.html>`_
    """


