# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from .accessible_list import AccessibleList as AccessibleList_bb240bde

class AccessibleListBoxList(AccessibleList_bb240bde):
    """
    Service Class

    Accessible list box lists are used by list boxes as container for the list items.
    
    In addition of the simple container functionality of the AccessibleList service the com.sun.star.accessibility.XAccessibleSelection interface is supported.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleListBoxList <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1AccessibleListBoxList.html>`_
    """


